#[repr(u64)]pub enum CaseSensitivity {
Sensitive = 0,
Insensitive = 1,
Mixed = 2,
}Expand description
Indicates whether the file name matching algorithm used by the file system should be case-sensitive, case-insensitive, or allow a combination of both styles of matching.
Variants
Sensitive = 0
Insensitive = 1
Mixed = 2
File system can support requests for both case-sensitive and case-insensitive matching behavior.