FilesystemPropertiesBuilder

Struct FilesystemPropertiesBuilder 

pub struct FilesystemPropertiesBuilder { /* private fields */ }
Builder for FilesystemProperties.

Implementations

Source

impl FilesystemPropertiesBuilder

pub fn name(&mut self, value: PathBuf) -> &mut Self

pub fn acl_inherit(&mut self, value: AclInheritMode) -> &mut Self

Controls how ACL entries inherited when files and directories created.

pub fn acl_mode(&mut self, value: Option<AclMode>) -> &mut Self

Controls how an ACL entry modified during a chmod operation.

pub fn atime(&mut self, value: bool) -> &mut Self

Controls whether the access time for files updated when they are read.

pub fn available(&mut self, value: i64) -> &mut Self

Read-only property that identifies the amount of disk space available to a dataset and all its children, assuming no other activity in the pool. Because disk space shared within a pool, available space can be limited by various factors including physical pool size, quotas, reservations, and other datasets within the pool.

pub fn can_mount(&mut self, value: CanMount) -> &mut Self

Controls whether a file system can be mounted.

pub fn case_sensitivity(&mut self, value: CaseSensitivity) -> &mut Self

Indicates whether the file name matching algorithm used by the file system should be case-sensitive, case-insensitive, or allow a combination of both styles of matching.

pub fn checksum(&mut self, value: Checksum) -> &mut Self

Security label Controls the checksum used to verify data integrity.

pub fn compression(&mut self, value: Compression) -> &mut Self

Enables or disables compression for a dataset.

pub fn compression_ratio(&mut self, value: f64) -> &mut Self

Read-only property that identifies the compression ratio achieved for a dataset, expressed as a multiplier.

pub fn copies(&mut self, value: Copies) -> &mut Self

Sets the number of copies of user data per file system. Available values are 1, 2, or 3. These copies are in addition to any pool-level redundancy. Disk space used by multiple copies of user data charged to the corresponding file and dataset, and counts against quotas and reservations. In addition, the used property updated when multiple copies enabled. Consider setting this property when the file system created because changing this property on an existing file system only affects newly written data.

pub fn create_txg(&mut self, value: Option<u64>) -> &mut Self

The birth time transaction group (TXG) of the object.

pub fn creation(&mut self, value: i64) -> &mut Self

Read-only property that identifies the date and time a dataset created.

pub fn dedup(&mut self, value: Dedup) -> &mut Self

Configures deduplication for a dataset.

pub fn devices(&mut self, value: bool) -> &mut Self

Controls whether device files in a file system can be opened.

pub fn dnode_size(&mut self, value: DnodeSize) -> &mut Self

Specifies a compatibility mode or literal value for the size of dnodes in the file system.

pub fn exec(&mut self, value: bool) -> &mut Self

Controls whether programs in a file system allowed to be executed. Also, when set to false, mmap(2) calls with PROT_EXEC disallowed.

pub fn filesystem_count(&mut self, value: Option<u64>) -> &mut Self

The total number of filesystems that exist under this location in the dataset tree. This value is only available when a filesystem_limit has been set somewhere in the tree under which the dataset resides.

pub fn filesystem_limit(&mut self, value: Option<u64>) -> &mut Self

Limits the number of filesystems that can be created on a dataset and its descendents.

pub fn guid(&mut self, value: Option<u64>) -> &mut Self

GUID of the dataset

pub fn mounted(&mut self, value: bool) -> &mut Self

Read-only property that indicates whether a file system, clone, or snapshot is currently mounted.

pub fn mount_point(&mut self, value: Option<PathBuf>) -> &mut Self

Controls the mount point used for this file system.

pub fn nbmand(&mut self, value: bool) -> &mut Self

pub fn normalization(&mut self, value: Normalization) -> &mut Self

Indicates whether the file system should perform a unicode normalization of file names whenever two filenames are compared, and which normalization algorithm should be used.

pub fn primary_cache(&mut self, value: CacheMode) -> &mut Self

Controls what is cached in the primary cache (ARC).

pub fn origin(&mut self, value: Option<String>) -> &mut Self

pub fn quota(&mut self, value: u64) -> &mut Self

Limits the amount of disk space a dataset and its descendants can consume.

pub fn readonly(&mut self, value: bool) -> &mut Self

Controls whether a dataset can be modified.

pub fn record_size(&mut self, value: u64) -> &mut Self

Specifies a suggested block size for files in a file system in bytes. The size specified must be a power of two greater than or equal to 512 and less than or equal to 128 KiB. If the large_blocks feature is enabled on the pool, the size may be up to 1 MiB.

pub fn redundant_metadata(&mut self, value: RedundantMetadata) -> &mut Self

Controls what types of metadata are stored redundantly

pub fn ref_compression_ratio(&mut self, value: f64) -> &mut Self

Compression ratio achieved for the referenced space of this snapshot.

pub fn referenced(&mut self, value: u64) -> &mut Self

Read-only property that identifies the amount of data accessible by a dataset, which might or might not be shared with other datasets in the pool.

pub fn ref_quota(&mut self, value: u64) -> &mut Self

Sets the amount of disk space a dataset can consume. This property enforces a hard limit on the amount of space used. This hard limit does not include disk space used by descendents, such as snapshots and clones.

pub fn ref_reservation(&mut self, value: u64) -> &mut Self

Sets the minimum amount of disk space is guaranteed to a dataset, not including descendants, such as snapshots and clones.

pub fn reservation(&mut self, value: u64) -> &mut Self

Sets the minimum amount of disk space guaranteed to a dataset and its descendants.

pub fn secondary_cache(&mut self, value: CacheMode) -> &mut Self

Controls what is cached in the secondary cache (L2ARC).

pub fn setuid(&mut self, value: bool) -> &mut Self

Controls whether the setuid bit is honored in a file system.

pub fn snap_dir(&mut self, value: SnapDir) -> &mut Self

Controls whether the .zfs directory is hidden or visible in the root of the file system

pub fn snapshot_count(&mut self, value: Option<u64>) -> &mut Self

The total number of snapshots that exist under this location in the dataset tree. This value is only available when a snapshot_limit has been set somewhere in the tree under which the dataset resides.

pub fn snapshot_limit(&mut self, value: Option<u64>) -> &mut Self

Limits the number of snapshots that can be created on a dataset and its descendents.

pub fn sync(&mut self, value: SyncMode) -> &mut Self

Controls the behavior of synchronous requests.

pub fn used(&mut self, value: u64) -> &mut Self

Read-only property that identifies the amount of disk space consumed by a dataset and all its descendants.

pub fn used_by_children(&mut self, value: u64) -> &mut Self

Read-only property that identifies the amount of disk space is used by children of this dataset, which would be freed if all the dataset’s children were destroyed.

pub fn used_by_dataset(&mut self, value: u64) -> &mut Self

Read-only property that identifies the amount of disk space is used by a dataset itself.

pub fn used_by_ref_reservation(&mut self, value: u64) -> &mut Self

Read-only property that identifies the amount of disk space is used by a refreservation set on a dataset.

pub fn used_by_snapshots(&mut self, value: u64) -> &mut Self

Read-only property that identifies the amount of disk space is consumed by snapshots of a dataset.

pub fn xattr(&mut self, value: bool) -> &mut Self

Indicates whether extended attributes are enabled or disabled.

pub fn jailed(&mut self, value: Option<bool>) -> &mut Self

Controls whether the dataset is managed from a jail.

pub fn log_bias(&mut self, value: LogBias) -> &mut Self

Provide a hint to ZFS about handling of synchronous requests in this dataset.

pub fn logical_referenced(&mut self, value: u64) -> &mut Self

The amount of space is “logically” accessible by this dataset.

pub fn logical_used(&mut self, value: u64) -> &mut Self

The amount of space is “logically” consumed by this dataset and all its descendents.

pub fn mls_label(&mut self, value: Option<String>) -> &mut Self

pub fn utf8_only(&mut self, value: Option<bool>) -> &mut Self

Indicates whether the file system should reject file names that include characters that are not present in the UTF-8 character code set. If this property is explicitly set to off, the normalization property must either not be explicitly set or be set to none.

pub fn version(&mut self, value: u64) -> &mut Self

Version (should 5)

pub fn written(&mut self, value: u64) -> &mut Self

Written?

pub fn volume_mode(&mut self, value: Option<VolumeMode>) -> &mut Self

Controls how the volume is exposed to the OS

pub fn vscan(&mut self, value: bool) -> &mut Self

Virus scan - not used outside solaris

pub fn unknown_properties( &mut self, value: HashMap<String, String>, ) -> &mut Self

User defined properties and properties this library failed to recognize.

pub fn build( &self, ) -> Result<FilesystemProperties, FilesystemPropertiesBuilderError>

Builds a new FilesystemProperties.

Errors

If a required field has not been initialized.

Source

impl FilesystemPropertiesBuilder

pub fn insert_unknown_property(&mut self, key: String, value: String)