pub struct Disk { /* private fields */ }Expand description
Basic building block of vdev.
It can be backed by a entire block device, a partition or a file. This particular structure represents backing of existing vdev. If disk is part of active zpool then it will also have error counts.
Implementations
Sourceimpl Disk
impl Disk
Sourcepub fn path(&self) -> &PathBuf
pub fn path(&self) -> &PathBuf
Path to a backing device or file. If path is relative, then it’s
relative to /dev/.
Sourcepub fn error_statistics(&self) -> &ErrorStatistics
pub fn error_statistics(&self) -> &ErrorStatistics
How many read, write and checksum errors device encountered since last reset.