pub struct FilesystemPropertiesBuilder { /* private fields */ }Expand description
Builder for FilesystemProperties.
Implementations
Sourceimpl FilesystemPropertiesBuilder
impl FilesystemPropertiesBuilder
pub fn name(&mut self, value: PathBuf) -> &mut Self
Sourcepub fn acl_inherit(&mut self, value: AclInheritMode) -> &mut Self
pub fn acl_inherit(&mut self, value: AclInheritMode) -> &mut Self
Controls how ACL entries inherited when files and directories created.
Sourcepub fn acl_mode(&mut self, value: Option<AclMode>) -> &mut Self
pub fn acl_mode(&mut self, value: Option<AclMode>) -> &mut Self
Controls how an ACL entry modified during a chmod operation.
Sourcepub fn atime(&mut self, value: bool) -> &mut Self
pub fn atime(&mut self, value: bool) -> &mut Self
Controls whether the access time for files updated when they are read.
Sourcepub fn available(&mut self, value: i64) -> &mut Self
pub fn available(&mut self, value: i64) -> &mut Self
Read-only property that identifies the amount of disk space available to a dataset and all its children, assuming no other activity in the pool. Because disk space shared within a pool, available space can be limited by various factors including physical pool size, quotas, reservations, and other datasets within the pool.
Sourcepub fn can_mount(&mut self, value: CanMount) -> &mut Self
pub fn can_mount(&mut self, value: CanMount) -> &mut Self
Controls whether a file system can be mounted.
Sourcepub fn case_sensitivity(&mut self, value: CaseSensitivity) -> &mut Self
pub fn case_sensitivity(&mut self, value: CaseSensitivity) -> &mut Self
Indicates whether the file name matching algorithm used by the file system should be case-sensitive, case-insensitive, or allow a combination of both styles of matching.
Sourcepub fn checksum(&mut self, value: Checksum) -> &mut Self
pub fn checksum(&mut self, value: Checksum) -> &mut Self
Security label Controls the checksum used to verify data integrity.
Sourcepub fn compression(&mut self, value: Compression) -> &mut Self
pub fn compression(&mut self, value: Compression) -> &mut Self
Enables or disables compression for a dataset.
Sourcepub fn compression_ratio(&mut self, value: f64) -> &mut Self
pub fn compression_ratio(&mut self, value: f64) -> &mut Self
Read-only property that identifies the compression ratio achieved for a dataset, expressed as a multiplier.
Sourcepub fn copies(&mut self, value: Copies) -> &mut Self
pub fn copies(&mut self, value: Copies) -> &mut Self
Sets the number of copies of user data per file system. Available values are 1, 2, or 3. These copies are in addition to any pool-level redundancy. Disk space used by multiple copies of user data charged to the corresponding file and dataset, and counts against quotas and reservations. In addition, the used property updated when multiple copies enabled. Consider setting this property when the file system created because changing this property on an existing file system only affects newly written data.
Sourcepub fn create_txg(&mut self, value: Option<u64>) -> &mut Self
pub fn create_txg(&mut self, value: Option<u64>) -> &mut Self
The birth time transaction group (TXG) of the object.
Sourcepub fn creation(&mut self, value: i64) -> &mut Self
pub fn creation(&mut self, value: i64) -> &mut Self
Read-only property that identifies the date and time a dataset created.
Sourcepub fn devices(&mut self, value: bool) -> &mut Self
pub fn devices(&mut self, value: bool) -> &mut Self
Controls whether device files in a file system can be opened.
Sourcepub fn dnode_size(&mut self, value: DnodeSize) -> &mut Self
pub fn dnode_size(&mut self, value: DnodeSize) -> &mut Self
Specifies a compatibility mode or literal value for the size of dnodes in the file system.
Sourcepub fn exec(&mut self, value: bool) -> &mut Self
pub fn exec(&mut self, value: bool) -> &mut Self
Controls whether programs in a file system allowed to be executed. Also, when set to
false, mmap(2) calls with PROT_EXEC disallowed.
Sourcepub fn filesystem_count(&mut self, value: Option<u64>) -> &mut Self
pub fn filesystem_count(&mut self, value: Option<u64>) -> &mut Self
The total number of filesystems that exist under this location in the dataset tree. This value is only available when a filesystem_limit has been set somewhere in the tree under which the dataset resides.
Sourcepub fn filesystem_limit(&mut self, value: Option<u64>) -> &mut Self
pub fn filesystem_limit(&mut self, value: Option<u64>) -> &mut Self
Limits the number of filesystems that can be created on a dataset and its descendents.
Sourcepub fn mounted(&mut self, value: bool) -> &mut Self
pub fn mounted(&mut self, value: bool) -> &mut Self
Read-only property that indicates whether a file system, clone, or snapshot is currently mounted.
Sourcepub fn mount_point(&mut self, value: Option<PathBuf>) -> &mut Self
pub fn mount_point(&mut self, value: Option<PathBuf>) -> &mut Self
Controls the mount point used for this file system.
Sourcepub fn normalization(&mut self, value: Normalization) -> &mut Self
pub fn normalization(&mut self, value: Normalization) -> &mut Self
Indicates whether the file system should perform a unicode normalization of file names whenever two filenames are compared, and which normalization algorithm should be used.
Sourcepub fn primary_cache(&mut self, value: CacheMode) -> &mut Self
pub fn primary_cache(&mut self, value: CacheMode) -> &mut Self
Controls what is cached in the primary cache (ARC).
pub fn origin(&mut self, value: Option<String>) -> &mut Self
Sourcepub fn quota(&mut self, value: u64) -> &mut Self
pub fn quota(&mut self, value: u64) -> &mut Self
Limits the amount of disk space a dataset and its descendants can consume.
Sourcepub fn readonly(&mut self, value: bool) -> &mut Self
pub fn readonly(&mut self, value: bool) -> &mut Self
Controls whether a dataset can be modified.
Sourcepub fn record_size(&mut self, value: u64) -> &mut Self
pub fn record_size(&mut self, value: u64) -> &mut Self
Specifies a suggested block size for files in a file system in bytes. The size specified must be a power of two greater than or equal to 512 and less than or equal to 128 KiB. If the large_blocks feature is enabled on the pool, the size may be up to 1 MiB.
Sourcepub fn redundant_metadata(&mut self, value: RedundantMetadata) -> &mut Self
pub fn redundant_metadata(&mut self, value: RedundantMetadata) -> &mut Self
Controls what types of metadata are stored redundantly
Sourcepub fn ref_compression_ratio(&mut self, value: f64) -> &mut Self
pub fn ref_compression_ratio(&mut self, value: f64) -> &mut Self
Compression ratio achieved for the referenced space of this snapshot.
Sourcepub fn referenced(&mut self, value: u64) -> &mut Self
pub fn referenced(&mut self, value: u64) -> &mut Self
Read-only property that identifies the amount of data accessible by a dataset, which might or might not be shared with other datasets in the pool.
Sourcepub fn ref_quota(&mut self, value: u64) -> &mut Self
pub fn ref_quota(&mut self, value: u64) -> &mut Self
Sets the amount of disk space a dataset can consume. This property enforces a hard limit on the amount of space used. This hard limit does not include disk space used by descendents, such as snapshots and clones.
Sourcepub fn ref_reservation(&mut self, value: u64) -> &mut Self
pub fn ref_reservation(&mut self, value: u64) -> &mut Self
Sets the minimum amount of disk space is guaranteed to a dataset, not including descendants, such as snapshots and clones.
Sourcepub fn reservation(&mut self, value: u64) -> &mut Self
pub fn reservation(&mut self, value: u64) -> &mut Self
Sets the minimum amount of disk space guaranteed to a dataset and its descendants.
Sourcepub fn secondary_cache(&mut self, value: CacheMode) -> &mut Self
pub fn secondary_cache(&mut self, value: CacheMode) -> &mut Self
Controls what is cached in the secondary cache (L2ARC).
Sourcepub fn setuid(&mut self, value: bool) -> &mut Self
pub fn setuid(&mut self, value: bool) -> &mut Self
Controls whether the setuid bit is honored in a file system.
Sourcepub fn snap_dir(&mut self, value: SnapDir) -> &mut Self
pub fn snap_dir(&mut self, value: SnapDir) -> &mut Self
Controls whether the .zfs directory is hidden or visible in the root of the file system
Sourcepub fn snapshot_count(&mut self, value: Option<u64>) -> &mut Self
pub fn snapshot_count(&mut self, value: Option<u64>) -> &mut Self
The total number of snapshots that exist under this location in the dataset tree. This value is only available when a snapshot_limit has been set somewhere in the tree under which the dataset resides.
Sourcepub fn snapshot_limit(&mut self, value: Option<u64>) -> &mut Self
pub fn snapshot_limit(&mut self, value: Option<u64>) -> &mut Self
Limits the number of snapshots that can be created on a dataset and its descendents.
Sourcepub fn sync(&mut self, value: SyncMode) -> &mut Self
pub fn sync(&mut self, value: SyncMode) -> &mut Self
Controls the behavior of synchronous requests.
Sourcepub fn used(&mut self, value: u64) -> &mut Self
pub fn used(&mut self, value: u64) -> &mut Self
Read-only property that identifies the amount of disk space consumed by a dataset and all its descendants.
Sourcepub fn used_by_children(&mut self, value: u64) -> &mut Self
pub fn used_by_children(&mut self, value: u64) -> &mut Self
Read-only property that identifies the amount of disk space is used by children of this dataset, which would be freed if all the dataset’s children were destroyed.
Sourcepub fn used_by_dataset(&mut self, value: u64) -> &mut Self
pub fn used_by_dataset(&mut self, value: u64) -> &mut Self
Read-only property that identifies the amount of disk space is used by a dataset itself.
Sourcepub fn used_by_ref_reservation(&mut self, value: u64) -> &mut Self
pub fn used_by_ref_reservation(&mut self, value: u64) -> &mut Self
Read-only property that identifies the amount of disk space is used by a refreservation set on a dataset.
Sourcepub fn used_by_snapshots(&mut self, value: u64) -> &mut Self
pub fn used_by_snapshots(&mut self, value: u64) -> &mut Self
Read-only property that identifies the amount of disk space is consumed by snapshots of a dataset.
Sourcepub fn xattr(&mut self, value: bool) -> &mut Self
pub fn xattr(&mut self, value: bool) -> &mut Self
Indicates whether extended attributes are enabled or disabled.
Sourcepub fn jailed(&mut self, value: Option<bool>) -> &mut Self
pub fn jailed(&mut self, value: Option<bool>) -> &mut Self
Controls whether the dataset is managed from a jail.
Sourcepub fn log_bias(&mut self, value: LogBias) -> &mut Self
pub fn log_bias(&mut self, value: LogBias) -> &mut Self
Provide a hint to ZFS about handling of synchronous requests in this dataset.
Sourcepub fn logical_referenced(&mut self, value: u64) -> &mut Self
pub fn logical_referenced(&mut self, value: u64) -> &mut Self
The amount of space is “logically” accessible by this dataset.
Sourcepub fn logical_used(&mut self, value: u64) -> &mut Self
pub fn logical_used(&mut self, value: u64) -> &mut Self
The amount of space is “logically” consumed by this dataset and all its descendents.
Sourcepub fn utf8_only(&mut self, value: Option<bool>) -> &mut Self
pub fn utf8_only(&mut self, value: Option<bool>) -> &mut Self
Indicates whether the file system should reject file names that include characters that are not present in the UTF-8 character code set. If this property is explicitly set to off, the normalization property must either not be explicitly set or be set to none.
Sourcepub fn volume_mode(&mut self, value: Option<VolumeMode>) -> &mut Self
pub fn volume_mode(&mut self, value: Option<VolumeMode>) -> &mut Self
Controls how the volume is exposed to the OS
Sourcepub fn unknown_properties(
&mut self,
value: HashMap<String, String>,
) -> &mut Self
pub fn unknown_properties( &mut self, value: HashMap<String, String>, ) -> &mut Self
User defined properties and properties this library failed to recognize.
Sourcepub fn build(
&self,
) -> Result<FilesystemProperties, FilesystemPropertiesBuilderError>
pub fn build( &self, ) -> Result<FilesystemProperties, FilesystemPropertiesBuilderError>
Sourceimpl FilesystemPropertiesBuilder
impl FilesystemPropertiesBuilder
pub fn insert_unknown_property(&mut self, key: String, value: String)